@@ -1,9 +1,9 @@
 import fs from'fs';
-const{execSync}=require('child_process');
+import{execSync}from'child_process';
 var stylezero_style_version=1;
 var allow_stylezero_execution=true;
 const stylezero_bin=process.platform==='win32'?'%LocalAppData%\\Programs\\StyleZero\\stylezero':'~/.local/opt/stylezero/stylezero';
-var __dir__=process.cwd();
+var __dir__=process.cwd().replaceAll('\\','/');
 export default function stylezero(){
 	return{
 		name:'stylezero',
